// Import D3 library
import * as d3 from 'd3';

// Define the map URL and listings URL
const mapUrl =
  'https://raw.githubusercontent.com/generalpiston/geojson-us-city-boundaries/master/cities/co/denver.json';
const listingsUrl =
  'https://raw.githubusercontent.com/shamdeed30/dataSrc/main/denver_listing_and_predictions.csv';
// 'https://raw.githubusercontent.com/shamdeed30/dataSrc/main/denverAirBnbListings.csv';

// Get Data
Promise.all([d3.json(mapUrl), d3.csv(listingsUrl)])
  .then(([mapData, csvData]) => {
    // Set up SVG container
    const width = 800;
    const height = 600;
    const svg = d3
      .select('body')
      .append('svg')
      .attr('width', width)
      .attr('height', height);

    // Define projection and path generator
    const projection = d3
      .geoMercator()
      .fitSize([width, height], mapData);
    const path = d3.geoPath().projection(projection);

    // Draw map
    svg
      .selectAll('path')
      .data(mapData.features)
      .enter()
      .append('path')
      .attr('d', path)
      .attr('fill', 'lightblue')
      .attr('stroke', 'black');

    // Parse CSV data
    const parsedCsvData = csvData.map((d) => ({
      latitude: +d.latitude,
      longitude: +d.longitude,
      overpriced: +d.overpriced,
      // Other properties from your CSV data
    }));

    // Draw Airbnb listings
    svg
      .selectAll('.listing')
      .data(parsedCsvData)
      .enter()
      .append('circle')
      .attr('class', 'listing')
      .attr(
        'cx',
        (d) => projection([d.longitude, d.latitude])[0],
      )
      .attr(
        'cy',
        (d) => projection([d.longitude, d.latitude])[1],
      )
      .attr('r', 1.5)
      // .attr('fill', 'red');
      .attr('fill', (d) => {
        if (d.overpriced === 1) {
          return 'red'; // Overpriced
        } else if (d.overpriced === 0) {
          return 'green'; // Not overpriced
        } else {
          return 'gray';
        }
      });
  })
  .catch((error) => {
    console.error('Error loading data:', error);
  });
